## Main authors ##

 * Danilo Bargen (gwrtheyrn)

## Contributors ##

 * Chris Glass (chrisglass) Small cleanups
 * Kristian Øllegaard (KristianOellegaard) Some refactoring ideas
 * Joel Sutter (schoeggu) Unicode Fix for OS X
